==> Devel-Cover-0.38.tar.gz: Devel-Cover-0.38/lib/Devel/Cover/Subroutine.pm <==
# Copyright 2004, Paul Johnson (pjcj@cpan.org)

# This software is free.  It is licensed under the same terms as Perl itself.

# The latest version of this software should be available from my homepage:
# http://www.pjcj.net

package Devel::Cover::Subroutine;

use strict;
use warnings;

our $VERSION = "0.38";

use base "Devel::Cover::Criterion";

sub covered    { $_[0][0][0] }
sub total      { 1 }
sub percentage { $_[0][0][0] ? 100 : 0 }
sub error      { !$_[0][0][0] }
sub name       { $_[0][0][1] }

sub calculate_summary
{
    my $self = shift;
    my ($db, $file) = @_;

    my $s = $db->{summary};

    $s->{$file}{subroutine}{total}++;
    $s->{$file}{total}{total}++;
    $s->{Total}{subroutine}{total}++;
    $s->{Total}{total}{total}++;

    if ($self->[0][0])
    {
        $s->{$file}{subroutine}{covered}++;
        $s->{$file}{total}{covered}++;
        $s->{Total}{subroutine}{covered}++;
        $s->{Total}{total}{covered}++;
    }
}

1

__END__

=head1 NAME

Devel::Cover::Statement - Code coverage metrics for Perl

=head1 SYNOPSIS

 use Devel::Cover::Statement;

=head1 DESCRIPTION

Module for storing subroutine coverage information.

=head1 SEE ALSO

 Devel::Cover::Criterion

=head1 METHODS

=head1 BUGS

Huh?

=head1 VERSION

Version 0.38 - 12th March 2004

=head1 LICENCE

Copyright 2001-2004, Paul Johnson (pjcj@cpan.org)

This software is free.  It is licensed under the same terms as Perl itself.

The latest version of this software should be available from my homepage:
http://www.pjcj.net

=cut

==> Devel-Cover-0.39.tar.gz: Devel-Cover-0.39/lib/Devel/Cover/Subroutine.pm <==
# Copyright 2004, Paul Johnson (pjcj@cpan.org)

# This software is free.  It is licensed under the same terms as Perl itself.

# The latest version of this software should be available from my homepage:
# http://www.pjcj.net

package Devel::Cover::Subroutine;

use strict;
use warnings;

our $VERSION = "0.39";

use base "Devel::Cover::Criterion";

sub covered    { $_[0][0] }
sub total      { 1 }
sub percentage { $_[0][0] ? 100 : 0 }
sub error      { !$_[0][0] }
sub name       { $_[0][1] }

sub calculate_summary
{
    my $self = shift;
    my ($db, $file) = @_;

    my $s = $db->{summary};

    $s->{$file}{subroutine}{total}++;
    $s->{$file}{total}{total}++;
    $s->{Total}{subroutine}{total}++;
    $s->{Total}{total}{total}++;

    if ($self->[0])
    {
        $s->{$file}{subroutine}{covered}++;
        $s->{$file}{total}{covered}++;
        $s->{Total}{subroutine}{covered}++;
        $s->{Total}{total}{covered}++;
    }
}

1

__END__

=head1 NAME

Devel::Cover::Statement - Code coverage metrics for Perl

=head1 SYNOPSIS

 use Devel::Cover::Statement;

=head1 DESCRIPTION

Module for storing subroutine coverage information.

=head1 SEE ALSO

 Devel::Cover::Criterion

=head1 METHODS

=head1 BUGS

Huh?

=head1 VERSION

Version 0.39 - 22nd March 2004

=head1 LICENCE

Copyright 2001-2004, Paul Johnson (pjcj@cpan.org)

This software is free.  It is licensed under the same terms as Perl itself.

The latest version of this software should be available from my homepage:
http://www.pjcj.net

=cut
